package android.app;

import android.content.Intent;
import android.content.pm.ParceledListSlice;
import android.graphics.Rect;
import android.os.Bundle;
import android.os.IBinder;
import android.os.RemoteException;
import android.view.IRecentsAnimationRunner;
import android.view.RemoteAnimationAdapter;
import android.window.TaskSnapshot;

import java.util.List;

import commons.annotations.Hidden;
import commons.annotations.NotInSdk;
import commons.annotations.MethodDescriptor;
import commons.utils.Build;

@NotInSdk
@SuppressWarnings("unused")
@Hidden(startVersion = Build.VERSION_CODES.Q)
public interface IActivityTaskManager {
    @Hidden(startVersion = Build.VERSION_CODES.Q)
    void registerTaskStackListener(ITaskStackListener listener) throws RemoteException;

    @Hidden(startVersion = Build.VERSION_CODES.Q)
    void unregisterTaskStackListener(ITaskStackListener listener) throws RemoteException;

    @Hidden(startVersion = Build.VERSION_CODES.Q)
    List<ActivityManager.RunningTaskInfo> getFilteredTasks(int maxNum, int ignoreActivityType, int ignoreWindowingMode) throws RemoteException;

    @Hidden(startVersion = Build.VERSION_CODES.Q)
    ParceledListSlice getRecentTasks(int maxNum, int flags, int userId) throws RemoteException;

    @Hidden(startVersion = Build.VERSION_CODES.Q)
    @MethodDescriptor(version = Build.VERSION_CODES.S, value = "(IZ)Landroid/window/TaskSnapshot;")
    @MethodDescriptor(version = Build.VERSION_CODES.S_V2, value = "(IZ)Landroid/window/TaskSnapshot;")
    @MethodDescriptor(version = Build.VERSION_CODES.T, value = "(IZ)Landroid/window/TaskSnapshot;")
    ActivityManager.TaskSnapshot getTaskSnapshot(int taskId, boolean reducedResolution) throws RemoteException;

    @Hidden(startVersion = Build.VERSION_CODES.Q)
    void startRecentsActivity(Intent intent, IAssistDataReceiver assistDataReceiver, IRecentsAnimationRunner recentsAnimationRunner) throws RemoteException;

    @Hidden(startVersion = Build.VERSION_CODES.Q)
    void cancelRecentsAnimation(boolean restoreHomeStackPosition) throws RemoteException;

    @Hidden(startVersion = Build.VERSION_CODES.Q)
    int startActivityFromRecents(int taskId, Bundle options) throws RemoteException;

    @Hidden(startVersion = Build.VERSION_CODES.Q)
    boolean setTaskWindowingModeSplitScreenPrimary(int taskId, int createMode, boolean toTop, boolean animate, Rect initialBounds, boolean showRecents) throws RemoteException;

    @Hidden(startVersion = Build.VERSION_CODES.Q)
    void removeAllVisibleRecentTasks() throws RemoteException;

    @Hidden(startVersion = Build.VERSION_CODES.Q)
    void cancelTaskWindowTransition(int taskId) throws RemoteException;

    @Hidden(startVersion = Build.VERSION_CODES.Q)
    int getLockTaskModeState() throws RemoteException;

    @Hidden(startVersion = Build.VERSION_CODES.Q)
    boolean removeTask(int taskId) throws RemoteException;

    @Hidden(startVersion = Build.VERSION_CODES.R)
    List<ActivityManager.RunningTaskInfo> getFilteredTasks(int maxNum, boolean filterOnlyVisibleRecents) throws RemoteException;

    @Hidden(startVersion = Build.VERSION_CODES.R)
    boolean setTaskWindowingModeSplitScreenPrimary(int taskId, boolean toTop) throws RemoteException;

    @Hidden(startVersion = Build.VERSION_CODES.R)
    void invalidateHomeTaskSnapshot(IBinder homeToken) throws RemoteException;

    @Hidden(startVersion = Build.VERSION_CODES.S)
    default void startRecentsActivity(Intent intent, long eventTime, IRecentsAnimationRunner recentsAnimationRunner) throws RemoteException {
        throw new RuntimeException();
    }

    @Hidden(startVersion = Build.VERSION_CODES.S)
    default boolean requestAssistDataForTask(IAssistDataReceiver receiver, int taskId, String callingPackageName) throws RemoteException {
        throw new RuntimeException();
    }

    @Hidden(startVersion = Build.VERSION_CODES.S)
    default ActivityTaskManager.RootTaskInfo getRootTaskInfo(int windowingMode, int activityType) throws RemoteException {
        throw new RuntimeException();
    }

    @Hidden(startVersion = Build.VERSION_CODES.S)
    default void registerRemoteAnimationForNextActivityStart(String packageName, RemoteAnimationAdapter adapter) throws RemoteException {
        throw new RuntimeException();
    }

    @Hidden(startVersion = Build.VERSION_CODES.S_V2)
    default void detachNavigationBarFromApp(IBinder transition) throws RemoteException {
        throw new RuntimeException();
    }

    @Hidden(startVersion = Build.VERSION_CODES.T)
    default void registerRemoteAnimationForNextActivityStart(String packageName,
            RemoteAnimationAdapter adapter, IBinder launchCookie) throws RemoteException {
        throw new RuntimeException();
    }

    @Hidden(startVersion = Build.VERSION_CODES.T)
    default TaskSnapshot takeTaskSnapshot(int taskId) throws RemoteException {
        throw new RuntimeException();
    }

    @Hidden(startVersion = Build.VERSION_CODES.U)
    default TaskSnapshot getTaskSnapshot(int taskId, boolean isLowResolution,
        boolean takeSnapshotIfNeeded) throws RemoteException {
        throw new RuntimeException();
    }

    @Hidden(startVersion = Build.VERSION_CODES.U)
    default void setFocusedTask(int taskId) throws RemoteException {
        throw new RuntimeException();
    }

    @Hidden(startVersion = Build.VERSION_CODES.U)
    default TaskSnapshot takeTaskSnapshot(int taskId, boolean updateCache) throws RemoteException {
        throw new RuntimeException();
    }

    @Hidden(startVersion = Build.VERSION_CODES.U)
    default boolean requestAssistDataForTask(IAssistDataReceiver receiver, int taskId, String callingPackageName, String callingAttributionTag) throws RemoteException {
        throw new RuntimeException();
    }
}